@@ -11,7 +11,7 @@ our @ISA         = qw(Exporter);
 our %EXPORT_TAGS = ( all => [ qw() ] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT      = qw();
-our $VERSION     = '0.14';
+our $VERSION     = '0.15';
 
 sub newhd {
     my $class = shift;
@@ -312,7 +312,7 @@ sub populate_values {
 
     if ($self->{filter} == 3) {
         if ($self->{is_init_attr}) {
-            $self->{att_hash} = {};
+            %{$self->{att_hash}} = () if %{$self->{att_hash}};
         }
         if ($self->{type} eq '@') {
             $self->{att_hash}{$self->{attr}} = $self->{value};
